@@ -133,12 +133,32 @@ class ParsingData:
 class FiltrationData(BaseModel):
     to_filter: ParsingData = ParsingData()
     page_number: int = 1
-    page_size: int = 10
-    order_by: Optional[str] = None
-    sort_by: Literal["asc", "desc"] = "asc"
+    page_size: int = None  # type: ignore
+    order_by: Optional[str] = None  # type: ignore
+    sort_by: Literal["asc", "desc"] = None  # type: ignore
 
     class Config:
         arbitrary_types_allowed = True
+        default_page_size: int = 10
+        default_order_by: Optional[str] = None
+        default_sort_by: Literal["asc", "desc"] = "asc"
+
+    @classmethod
+    @validator("page_size", pre=True)
+    def _pre_validate_page_size(cls, page_size: Optional[int]) -> int:
+        return page_size or cls.Config.default_page_size
+
+    @classmethod
+    @validator("order_by", pre=True)
+    def _pre_validate_order_by(cls, order_by: Optional[str]) -> Optional[str]:
+        return order_by or cls.Config.default_order_by
+
+    @classmethod
+    @validator("sort_by", pre=True)
+    def _pre_validate_sort_by(
+        cls, sort_by: Optional[Literal["asc", "desc"]]
+    ) -> Literal["asc", "desc"]:
+        return sort_by or cls.Config.default_sort_by
 
     def __get_sort_spec(self) -> list[ModelSortSpec]:
         return [_split_field(self.order_by) | {"direction": self.sort_by}]  # type: ignore
